@@ -1,3 +1,9 @@
+"""
+This class receives callbacks from the BooleanExpressionTree in order to determine if a condition,
+is true or false for a specific node.  The BooleanExpressionTree takes care of combining the results
+of each condition to determine the results of the entire boolean expression.
+"""
+
 from utils import *
 
 from enums import CEnum
@@ -6,17 +12,12 @@ from exceptions import WhereClauseException
 from boolean_expressions.evaluation_engine import EvaluationEngine
 
 
-'''
-This class receives callbacks from the BooleanExpressionTree in order to determine if a condition,
-is true or false for a specific node.  The BooleanExpressionTree takes care of combining the results
-of each condition to determine the results of the entire boolean expression.
-'''
 class WhereClauseEvaluationEngine(EvaluationEngine):
     OPERATORS = CEnum(("EQ", "NEQ", "GT", "LT", "GTE", "LTE", "IN"))
     OPERATOR_TOKENS = ("==", "!=", ">", "<", ">=", "<=", "in")
     OPERATOR_TOKENS_SET = frozenset(OPERATOR_TOKENS)
 
-    OPERAND_TYPES = CEnum(("STRING","INT","FLOAT","BOOL","NULL","DICTIONARY","LIST"))
+    OPERAND_TYPES = CEnum(("STRING", "INT", "FLOAT", "BOOL", "NULL", "DICTIONARY", "LIST"))
     NUMBER_TYPES = frozenset((OPERAND_TYPES.INT, OPERAND_TYPES.FLOAT))
 
     def get_operator_index(self, tokens):
@@ -28,7 +29,7 @@ class WhereClauseEvaluationEngine(EvaluationEngine):
 
     def get_operand_type_and_value(self, node, operand):
         if len(operand) == 1:
-            if operand[0].isdigit() or (operand[0][0]=='-' and operand[0][1:].isdigit()):
+            if operand[0].isdigit() or (operand[0][0] == '-' and operand[0][1:].isdigit()):
                 return WhereClauseEvaluationEngine.OPERAND_TYPES.INT, int(operand[0])
 
             elif operand[0][0] == operand[0][-1] and (operand[0][0] == '"' or operand[0][0] == "'"):
@@ -41,7 +42,7 @@ class WhereClauseEvaluationEngine(EvaluationEngine):
                 return WhereClauseEvaluationEngine.OPERAND_TYPES.BOOL, False
 
             elif operand[0].lower() == "null":
-                return WhereClauseEvaluationEngine.OPERAND_TYPES.NULL, None            
+                return WhereClauseEvaluationEngine.OPERAND_TYPES.NULL, None
 
             else:
                 try:
@@ -56,10 +57,10 @@ class WhereClauseEvaluationEngine(EvaluationEngine):
 
         if not found:
             return None, None
-            
+
         value = values[0]
 
-        if value == None:
+        if value is None:
             return WhereClauseEvaluationEngine.NULL, value
 
         elif isinstance(value, bool):
@@ -97,25 +98,26 @@ class WhereClauseEvaluationEngine(EvaluationEngine):
             roperand_tokens = tokens[operator_index + 1:]
 
             return {
-                WhereClauseEvaluationEngine.OPERATORS.EQ : self.evaluate_equality,
-                WhereClauseEvaluationEngine.OPERATORS.NEQ : self.evaluate_inequality,
-                WhereClauseEvaluationEngine.OPERATORS.GT : self.evaluate_greater_than,
-                WhereClauseEvaluationEngine.OPERATORS.GTE : self.evaluate_greater_than_or_equal,
-                WhereClauseEvaluationEngine.OPERATORS.LT : self.evaluate_less_than,
-                WhereClauseEvaluationEngine.OPERATORS.LTE : self.evaluate_less_than_or_equal,
-                WhereClauseEvaluationEngine.OPERATORS.IN : self.evaluate_key_exists
+                WhereClauseEvaluationEngine.OPERATORS.EQ: self.evaluate_equality,
+                WhereClauseEvaluationEngine.OPERATORS.NEQ: self.evaluate_inequality,
+                WhereClauseEvaluationEngine.OPERATORS.GT: self.evaluate_greater_than,
+                WhereClauseEvaluationEngine.OPERATORS.GTE: self.evaluate_greater_than_or_equal,
+                WhereClauseEvaluationEngine.OPERATORS.LT: self.evaluate_less_than,
+                WhereClauseEvaluationEngine.OPERATORS.LTE: self.evaluate_less_than_or_equal,
+                WhereClauseEvaluationEngine.OPERATORS.IN: self.evaluate_key_exists
             }[operator](node, loperand_tokens, roperand_tokens)
 
     def evaluate_equality(self, node, loperand_tokens, roperand_tokens):
         loperand_type, loperand_value = self.get_operand_type_and_value(node, loperand_tokens)
         roperand_type, roperand_value = self.get_operand_type_and_value(node, roperand_tokens)
 
-        if  loperand_type == roperand_type or (loperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES and roperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES):
+        if loperand_type == roperand_type or (
+                loperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES and roperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES):
             return loperand_value == roperand_value
         else:
             return False
 
-        #raise WhereClauseException("%s and %s are not comparable" % (''.join(loperand_tokens), ''.join(roperand_tokens)) )
+            #raise WhereClauseException("%s and %s are not comparable" % (''.join(loperand_tokens), ''.join(roperand_tokens)) )
 
     def evaluate_inequality(self, node, loperand_tokens, roperand_tokens):
         return not self.evaluate_equality(node, loperand_tokens, roperand_tokens)
@@ -127,7 +129,8 @@ class WhereClauseEvaluationEngine(EvaluationEngine):
         if loperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES and roperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES:
             return loperand_value > roperand_value
 
-        raise WhereClauseException("%s > %s is an invalid operation for these types" % (''.join(loperand_tokens), ''.join(roperand_tokens)) )
+        raise WhereClauseException(
+            "%s > %s is an invalid operation for these types" % (''.join(loperand_tokens), ''.join(roperand_tokens)))
 
     def evaluate_greater_than_or_equal(self, node, loperand_tokens, roperand_tokens):
         return not self.evaluate_less_than(node, loperand_tokens, roperand_tokens)
@@ -139,7 +142,8 @@ class WhereClauseEvaluationEngine(EvaluationEngine):
         if loperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES and roperand_type in WhereClauseEvaluationEngine.NUMBER_TYPES:
             return loperand_value < roperand_value
 
-        raise WhereClauseException("%s < %s is an invalid operation for these types" % (''.join(loperand_tokens), ''.join(roperand_tokens)) )
+        raise WhereClauseException(
+            "%s < %s is an invalid operation for these types" % (''.join(loperand_tokens), ''.join(roperand_tokens)))
 
     def evaluate_less_than_or_equal(self, node, loperand_tokens, roperand_tokens):
         return not self.evaluate_greater_than(node, loperand_tokens, roperand_tokens)
@@ -147,11 +151,12 @@ class WhereClauseEvaluationEngine(EvaluationEngine):
     def evaluate_key_exists(self, node, loperand_tokens, roperand_tokens):
         roperand_type, roperand_value = self.get_operand_type_and_value(node, roperand_tokens)
 
-        if roperand_type == None:
+        if roperand_type is None:
             raise WhereClauseException("could not find node at sub path \"%s\"" % ' '.join(roperand_tokens))
 
         elif roperand_type != WhereClauseEvaluationEngine.OPERAND_TYPES.DICTIONARY:
-            raise WhereClauseException('"in" operator can only be used on objects. Item at path "%s"' % ' '.join(roperand_tokens))
+            raise WhereClauseException(
+                '"in" operator can only be used on objects. Item at path "%s"' % ' '.join(roperand_tokens))
 
         else:
             found, nodes = get_elements_by_path_tokens(roperand_value, loperand_tokens)
